==> E-1.5.tgz: E/PROVER/e_version.h <==
/*-----------------------------------------------------------------------

File  : e_version.h

Author: Stephan Schulz (schulz@eprover.org)

Contents
 
  Define global macro for version number and meta-information. 

  Copyright 2009 by the author.
  This code is released under the GNU General Public Licence and
  the GNU Lesser General Public License.
  See the file COPYING in the main E directory for details..
  Run "eprover -h" for contact information.

Changes

<1> Tue Feb 24 00:26:41 CET 2009
    New

-----------------------------------------------------------------------*/

#ifndef E_VERSION

#define E_VERSION



/*---------------------------------------------------------------------*/
/*                    Data type declarations                           */
/*---------------------------------------------------------------------*/




/*---------------------------------------------------------------------*/
/*                Exported Functions and Variables                     */
/*---------------------------------------------------------------------*/

/* cvs tag E-1-5 */
#define VERSION      "1.5"

#define E_NICKNAME     "Pussimbing"

#define E_URL "http://www.eprover.org"

#define STS_MAIL "schulz@eprover.org"
#define STS_COPYRIGHT "Copyright 1998-2011 by Stephan Schulz"
#define STS_SNAIL "Stephan Schulz (I4)\nTechnische Universitaet Muenchen\nInstitut fuer Informatik\nBoltzmannstrasse 3\n85748 Garching bei Muenchen\nGermany\n"


#endif

/*---------------------------------------------------------------------*/
/*                        End of File                                  */
/*---------------------------------------------------------------------*/

==> E-1.6.tgz: E/PROVER/e_version.h <==
/*-----------------------------------------------------------------------

File  : e_version.h

Author: Stephan Schulz (schulz@eprover.org)

Contents
 
  Define global macro for version number and meta-information. 

  Copyright 2009-2012 by the author.
  This code is released under the GNU General Public Licence and
  the GNU Lesser General Public License.
  See the file COPYING in the main E directory for details..
  Run "eprover -h" for contact information.

Changes

<1> Tue Feb 24 00:26:41 CET 2009
    New

-----------------------------------------------------------------------*/

#ifndef E_VERSION

#define E_VERSION



/*---------------------------------------------------------------------*/
/*                    Data type declarations                           */
/*---------------------------------------------------------------------*/




/*---------------------------------------------------------------------*/
/*                Exported Functions and Variables                     */
/*---------------------------------------------------------------------*/

/* git tag E-1-6 */
#define VERSION      "1.6"

#define E_NICKNAME     "Tiger Hill"

#define E_URL "http://www.eprover.org"

#define STS_MAIL "schulz@eprover.org"
#define STS_COPYRIGHT "Copyright 1998-2012 by Stephan Schulz"
#define STS_SNAIL "Stephan Schulz (I4)\nTechnische Universitaet Muenchen\nInstitut fuer Informatik\nBoltzmannstrasse 3\n85748 Garching bei Muenchen\nGermany\n"


#endif

/*---------------------------------------------------------------------*/
/*                        End of File                                  */
/*---------------------------------------------------------------------*/
